==> react-molecule-breadcrumb-1.18.0.tgz: package/lib/index.js <==
/* eslint-disable react/prop-types */
import PropTypes from 'prop-types';
import React, { useState } from 'react';
import Chevronright from '@s-ui/react-icons/lib/Chevronright';
import cx from 'classnames';

var breadcrumbClassName = function breadcrumbClassName(_ref) {
  var isExpanded = _ref.isExpanded,
      isScrollable = _ref.isScrollable;
  return cx('sui-BreadcrumbBasic', {
    'is-expanded': isExpanded,
    'is-scrollable': isScrollable
  });
};

export default function BreadcrumbBasic(_ref2) {
  var items = _ref2.items,
      icon = _ref2.icon,
      Link = _ref2.linkFactory,
      _ref2$isScrollable = _ref2.isScrollable,
      isScrollable = _ref2$isScrollable === void 0 ? false : _ref2$isScrollable;

  var _useState = useState(false),
      isExpanded = _useState[0],
      setIsExpanded = _useState[1];

  var expandBreadcrumb = function expandBreadcrumb() {
    return setIsExpanded(true);
  };

  var IconAngle = icon || Chevronright;
  var numItems = items.length - 1;
  return React.createElement("nav", {
    "aria-label": "breadcrumb",
    role: "navigation"
  }, React.createElement("div", {
    className: breadcrumbClassName({
      isExpanded: isExpanded,
      isScrollable: isScrollable
    })
  }, React.createElement("button", {
    onClick: expandBreadcrumb,
    className: "sui-BreadcrumbBasic-btn"
  }, "..."), React.createElement("ul", {
    className: "sui-BreadcrumbBasic-list"
  }, items.map(function (_ref3, index) {
    var url = _ref3.url,
        label = _ref3.label;
    return React.createElement("li", {
      className: "sui-BreadcrumbBasic-listItem",
      key: index
    }, index !== 0 && index <= numItems && React.createElement(IconAngle, {
      svgClass: "sui-BreadcrumbBasic-icon"
    }), url ? React.createElement(Link, {
      to: url,
      href: url,
      className: "sui-BreadcrumbBasic-link"
    }, label) : label);
  }))));
}
BreadcrumbBasic.displayName = 'BreadcrumbBasic';
BreadcrumbBasic.defaultProps = {
  linkFactory: function linkFactory(_ref4) {
    var to = _ref4.to,
        href = _ref4.href,
        className = _ref4.className,
        children = _ref4.children;
    return React.createElement("a", {
      href: to || href,
      className: className
    }, children);
  }
};

==> react-molecule-breadcrumb-1.19.0.tgz: package/lib/index.js <==
/* eslint-disable react/prop-types */
import PropTypes from 'prop-types';
import React, { useState } from 'react';
import Chevronright from '@s-ui/react-icons/lib/Chevronright';
import cx from 'classnames';

var breadcrumbClassName = function breadcrumbClassName(_ref) {
  var isExpanded = _ref.isExpanded,
      isScrollable = _ref.isScrollable;
  return cx('sui-BreadcrumbBasic', {
    'is-expanded': isExpanded,
    'is-scrollable': isScrollable
  });
};

export default function BreadcrumbBasic(_ref2) {
  var items = _ref2.items,
      icon = _ref2.icon,
      Link = _ref2.linkFactory,
      _ref2$isScrollable = _ref2.isScrollable,
      isScrollable = _ref2$isScrollable === void 0 ? false : _ref2$isScrollable;

  var _useState = useState(false),
      isExpanded = _useState[0],
      setIsExpanded = _useState[1];

  var expandBreadcrumb = function expandBreadcrumb() {
    return setIsExpanded(true);
  };

  var IconAngle = icon || Chevronright;
  var numItems = items.length - 1;
  return /*#__PURE__*/React.createElement("nav", {
    "aria-label": "breadcrumb",
    role: "navigation"
  }, /*#__PURE__*/React.createElement("div", {
    className: breadcrumbClassName({
      isExpanded: isExpanded,
      isScrollable: isScrollable
    })
  }, /*#__PURE__*/React.createElement("button", {
    onClick: expandBreadcrumb,
    className: "sui-BreadcrumbBasic-btn"
  }, "..."), /*#__PURE__*/React.createElement("ul", {
    className: "sui-BreadcrumbBasic-list"
  }, items.map(function (_ref3, index) {
    var url = _ref3.url,
        label = _ref3.label;
    return /*#__PURE__*/React.createElement("li", {
      className: "sui-BreadcrumbBasic-listItem",
      key: index
    }, index !== 0 && index <= numItems && /*#__PURE__*/React.createElement(IconAngle, {
      svgClass: "sui-BreadcrumbBasic-icon"
    }), url ? /*#__PURE__*/React.createElement(Link, {
      to: url,
      href: url,
      className: "sui-BreadcrumbBasic-link"
    }, label) : label);
  }))));
}
BreadcrumbBasic.displayName = 'BreadcrumbBasic';
BreadcrumbBasic.defaultProps = {
  linkFactory: function linkFactory(_ref4) {
    var to = _ref4.to,
        href = _ref4.href,
        className = _ref4.className,
        children = _ref4.children;
    return /*#__PURE__*/React.createElement("a", {
      href: to || href,
      className: className
    }, children);
  }
};
